# -*- coding: utf-8 -*-
# Generated by Django 1.11.18 on 2019-01-15 23:48
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Record',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('create_time', models.DateTimeField()),
                ('message', models.TextField()),
                ('level', models.SmallIntegerField()),
                ('level_name', models.CharField(max_length=16)),
                ('function', models.CharField(max_length=80)),
                ('module', models.CharField(max_length=80)),
                ('path', models.CharField(max_length=260)),
                ('filename', models.CharField(max_length=80)),
                ('line', models.IntegerField()),
                ('logger', models.CharField(max_length=80)),
                ('process', models.IntegerField()),
                ('process_name', models.CharField(max_length=80)),
                ('thread', models.IntegerField()),
                ('thread_name', models.CharField(max_length=80)),
            ],
        ),
    ]
