"""Django Database Log

"""

from .handlers import DBLogHandler


__title__ = 'dblog'
__version__ = '0.2.0'
__build__ = 0x000200
__author__ = 'Grant Jenks'
__license__ = 'Apache 2.0'
__copyright__ = '2018-2019, Grant Jenks'
